@@ -25,11 +25,6 @@ use Audio::Nama::Object qw(
     			on_exit
 				 );
 
-initialize();
-
-sub initialize {
-	%by_name = ();	
-}
 sub new {
 	my $class = shift;	
 	my %vals = @_;
@@ -40,7 +35,7 @@ sub new {
 	#print "object class: $class, object type: ", ref $self, $/;
 	$by_name{ $self->name } = $self;
 	$self->initialize_ecasound();
-	$Audio::Nama::this_engine = $self;
+	$this_engine = $self;
 }
 sub initialize_ecasound { 
 	my $self = shift;
@@ -113,7 +108,7 @@ sub eval_iam {
 	$this_engine->{socket}->send("$cmd\r\n");
 	my $buf;
 	# get socket reply, restart ecasound on error
-	my $result = $this_engine->{socket}->recv($buf, 65536);
+	my $result = $this_engine->{socket}->recv($buf, $config->{engine_command_output_buffer_size});
 	defined $result or restart_ecasound(), return;
 
 	my ($return_value, $setup_length, $type, $reply) =
